Correlation
===========
.. automodule:: lsl.correlator.fx

Baseline Utilities
------------------
.. autofunction:: lsl.correlator.uvUtils.getBaselines
.. autofunction:: lsl.correlator.uvUtils.baseline2antenna
.. autofunction:: lsl.correlator.uvUtils.antenna2baseline

Computing *uvw* Coordinates
---------------------------
.. autofunction:: lsl.correlator.uvUtils.computeUVW
.. autofunction:: lsl.correlator.uvUtils.computeUVTrack

FX Correlator
-------------
.. autofunction:: lsl.correlator.fx.blackmanWindow
.. autofunction:: lsl.correlator.fx.sincWindow
.. autofunction:: lsl.correlator.fx.polyphaseFilter
.. autofunction:: lsl.correlator.fx.correlate
.. autofunction:: lsl.correlator.fx.FXCorrelator

Visibility Visualization
------------------------
.. automodule:: lsl.correlator.visUtils
   :members:

